==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/test/ui/internal/util/ContextIds.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.test.ui.internal.util;

public class ContextIds {
	
	//add deployment action
	public static final String ADD_DEP_ACT = ".adpa0001";
	//add SUT action
	public static final String ADD_SUT_ACT = ".asta0001";
	//add testcase action
	public static final String ADD_TCS_ACT = ".atca0001";	
	//add test component action
	public static final String ADD_TCOMP_ACT = ".atcp0001";	
	//add test suite child action
	public static final String ADD_SUITE_CHILD_ACT = ".ashd0001";	
	//add location action
	public static final String ADD_LOC_ACT = ".aloc0001";	
	
	//deployment form	
	public static final String DEPL_FORM = ".depf0001";	
	public static final String DEPL_TEXT_FORM = ".depf0002";		
	public static final String DEPL_NAME_FORM = ".depf0003";
			
	//location form	
	public static final String LOC_FORM = ".locf0001";	
	public static final String LOC_DETAIL_FORM = ".locf0002";	
	public static final String LOC_COMMON_FORM = ".locf0003";	
	public static final String LOC_LOC_FORM = ".locf0004";	
	public static final String LOC_LOCTREE_FORM = ".locf0005";	
	
	//machine details page
	public static final String MACHINE_DET_PAGE = ".medt0001";	
	public static final String MACHINE_TEXT_PAGE = ".medt0002";	
	
	//sut form
	public static final String SUT_FORM = ".sutf0001";	
	public static final String SUT_SECTION_FORM = ".sutf0002";	
	public static final String SUT_TREE_FORM = ".sutf0003";	
	public static final String SUT_NAME_FORM = ".sutf0004";	
	
	//testcase form
	public static final String TESTCASE_FORM = ".tcsf0001";	
	public static final String TESTCASE_NAME_FORM = ".tcsf0002";	
	public static final String TESTCASE_TREE_FORM = ".tcsf0003";	
	public static final String TESTCASE_SECT_FORM = ".tcsf0004";	
	
	//test components form
	public static final String TESTCOMP_FORM = ".tcpf0001";	
	public static final String TESTCOMP_COMP_FORM = ".tcpf0002";	
	public static final String TESTCOMP_NAME_FORM = ".tcpf0003";	
	public static final String TESTCOMP_TREE_FORM = ".tcpf0004";
	
	//test suite form	
	public static final String TESTSUITE_FORM = ".tstf0001";	
	public static final String TESTSUITE_FILE_FORM = ".tstf0002";	
	public static final String TESTSUITE_TYPE_FORM = ".tstf0003";	
	public static final String TESTSUITE_GEN_FORM = ".tstf0004";	

    //execution navigator
	public static final String EXEC_NAVIGATOR = ".enav0001";
	public static final String EXEC_OPEN_EDITOR_ACT = ".enav0002";
	public static final String EXEC_TOGGLE_ACT = ".enav0003";
	public static final String EXEC_TOGGLEF_ACT = ".enav0004";	
	public static final String EXEC_DLG = ".enav0005";	
	public static final String EXEC_SHOW_RUN_DLG = ".enav0006";	
	public static final String EXEC_SHOW_END_DLG = ".enav0007";	

    //test navigator			
	public static final String TEST_NAVIGATOR = ".tnav0001";	
	public static final String OPEN_EDITOR_ACT = ".tnav0002";	
	public static final String OPEN_REPORT_ACT = ".tnav0003";	
	public static final String PREPARE_RUN_ACT = ".tnav0004";	
	public static final String RUN_ACT = ".tnav0005";	
	public static final String TOGGLE_CHILD_ACT = ".tnav0006";	
	public static final String TOGGLE_FOLDER_ACT = ".tnav0007";
	
	//report generator pref page
	public static final String REP_GEN_PREF_CONT = ".rgpp0001";	
	public static final String REP_GEN_PREF_ADDB = ".rgpp0002";	
	public static final String REP_GEN_PREF_DELB = ".rgpp0003";	
	public static final String REP_GEN_PREF_EDITB = ".rgpp0004";	
	public static final String REP_GEN_PREF_TESTB = ".rgpp0005";	
	public static final String REP_GEN_PREF_BCDLG = ".rgpp0006";	
	public static final String REP_GEN_PREF_DLG = ".rgpp0007";	
	public static final String REP_GEN_PREF_BDDLG = ".rgpp0008";	
	public static final String REP_GEN_PREF_BJDLG = ".rgpp0009";	
	public static final String REP_GEN_PREF_CLAPDLG = ".rgpp0010";	
	public static final String REP_GEN_PREF_CLASNDLG = ".rgpp0011";	
	public static final String REP_GEN_PREF_NDLG = ".rgpp0012";	
	public static final String REP_GEN_PREF_TABLE = ".rgpp0013";	
	
	//test preference page
	public static final String TEST_PREF_CONT = ".tgpp0001";	
	public static final String TEST_PREF_EDIT_CONT = ".tgpp0002";	
	public static final String TEST_PREF_HOST_CONT = ".tgpp0003";	
	public static final String TEST_PREF_PORT_CONT = ".tgpp0004";	
	public static final String TEST_PREF_SAVE_CONT = ".tgpp0005";	
	
	//report wizard page
	public static final String REPORT_WIZ_PAGE = ".rwiz0001";	
	public static final String REPORT_WIZ_EDIT_PAGE = ".rwiz0002";	
	public static final String REPORT_WIZ_TABLE_PAGE = ".rwiz0003";	
	
	//test association preference page
	public static final String ASSOC_PREF_CONT = ".tasp0001";	
	
	//execution editor
	public static final String EXEC_EDIT_OVERVIEW = ".exed0001";	
	public static final String EXEC_EDIT_EVENTS = ".exed0002";	
	
}

==> hyades.source_1.2.1_20040126_0954.zip: org/eclipse/hyades/test/ui/internal/util/ContextIds.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.test.ui.internal.util;

public class ContextIds {
	
	//add deployment action
	public static final String ADD_DEP_ACT = ".adpa0001";
	//add SUT action
	public static final String ADD_SUT_ACT = ".asta0001";
	//add testcase action
	public static final String ADD_TCS_ACT = ".atca0001";	
	//add test component action
	public static final String ADD_TCOMP_ACT = ".atcp0001";	
	//add test suite child action
	public static final String ADD_SUITE_CHILD_ACT = ".ashd0001";	
	//add location action
	public static final String ADD_LOC_ACT = ".aloc0001";	
	
	//deployment form	
	public static final String DEPL_FORM = ".depf0001";	
	public static final String DEPL_TEXT_FORM = ".depf0002";		
	public static final String DEPL_NAME_FORM = ".depf0003";
			
	//location form	
	public static final String LOC_FORM = ".locf0001";	
	public static final String LOC_DETAIL_FORM = ".locf0002";	
	public static final String LOC_COMMON_FORM = ".locf0003";	
	public static final String LOC_LOC_FORM = ".locf0004";	
	public static final String LOC_LOCTREE_FORM = ".locf0005";	
	
	//machine details page
	public static final String MACHINE_DET_PAGE = ".medt0001";	
	public static final String MACHINE_TEXT_PAGE = ".medt0002";	
	
	//sut form
	public static final String SUT_FORM = ".sutf0001";	
	public static final String SUT_SECTION_FORM = ".sutf0002";	
	public static final String SUT_TREE_FORM = ".sutf0003";	
	public static final String SUT_NAME_FORM = ".sutf0004";	
	
	//testcase form
	public static final String TESTCASE_FORM = ".tcsf0001";	
	public static final String TESTCASE_NAME_FORM = ".tcsf0002";	
	public static final String TESTCASE_TREE_FORM = ".tcsf0003";	
	public static final String TESTCASE_SECT_FORM = ".tcsf0004";	
	
	//test components form
	public static final String TESTCOMP_FORM = ".tcpf0001";	
	public static final String TESTCOMP_COMP_FORM = ".tcpf0002";	
	public static final String TESTCOMP_NAME_FORM = ".tcpf0003";	
	public static final String TESTCOMP_TREE_FORM = ".tcpf0004";
	
	//test suite form	
	public static final String TESTSUITE_FORM = ".tstf0001";	
	public static final String TESTSUITE_FILE_FORM = ".tstf0002";	
	public static final String TESTSUITE_TYPE_FORM = ".tstf0003";	
	public static final String TESTSUITE_GEN_FORM = ".tstf0004";	

    //execution navigator
	public static final String EXEC_NAVIGATOR = ".enav0001";
	public static final String EXEC_OPEN_EDITOR_ACT = ".enav0002";
	public static final String EXEC_TOGGLE_ACT = ".enav0003";
	public static final String EXEC_TOGGLEF_ACT = ".enav0004";	
	public static final String EXEC_DLG = ".enav0005";	
	public static final String EXEC_SHOW_RUN_DLG = ".enav0006";	
	public static final String EXEC_SHOW_END_DLG = ".enav0007";	
	public static final String STOP_ACT = ".enav0008";
	public static final String SUSPEND_ACT = ".enav0009";
	public static final String RESUME_ACT = ".enav0010";

    //test navigator			
	public static final String TEST_NAVIGATOR = ".tnav0001";	
	public static final String OPEN_EDITOR_ACT = ".tnav0002";	
	public static final String OPEN_REPORT_ACT = ".tnav0003";	
	public static final String PREPARE_RUN_ACT = ".tnav0004";	
	public static final String RUN_ACT = ".tnav0005";	
	public static final String TOGGLE_CHILD_ACT = ".tnav0006";	
	public static final String TOGGLE_FOLDER_ACT = ".tnav0007";
	
	//report generator pref page
	public static final String REP_GEN_PREF_CONT = ".rgpp0001";	
	public static final String REP_GEN_PREF_ADDB = ".rgpp0002";	
	public static final String REP_GEN_PREF_DELB = ".rgpp0003";	
	public static final String REP_GEN_PREF_EDITB = ".rgpp0004";	
	public static final String REP_GEN_PREF_TESTB = ".rgpp0005";	
	public static final String REP_GEN_PREF_BCDLG = ".rgpp0006";	
	public static final String REP_GEN_PREF_DLG = ".rgpp0007";	
	public static final String REP_GEN_PREF_BDDLG = ".rgpp0008";	
	public static final String REP_GEN_PREF_BJDLG = ".rgpp0009";	
	public static final String REP_GEN_PREF_CLAPDLG = ".rgpp0010";	
	public static final String REP_GEN_PREF_CLASNDLG = ".rgpp0011";	
	public static final String REP_GEN_PREF_NDLG = ".rgpp0012";	
	public static final String REP_GEN_PREF_TABLE = ".rgpp0013";	
	
	//test preference page
	public static final String TEST_PREF_CONT = ".tgpp0001";	
	public static final String TEST_PREF_EDIT_CONT = ".tgpp0002";	
	public static final String TEST_PREF_HOST_CONT = ".tgpp0003";	
	public static final String TEST_PREF_PORT_CONT = ".tgpp0004";	
	public static final String TEST_PREF_SAVE_CONT = ".tgpp0005";	
	
	//report wizard page
	public static final String REPORT_WIZ_PAGE = ".rwiz0001";	
	public static final String REPORT_WIZ_EDIT_PAGE = ".rwiz0002";	
	public static final String REPORT_WIZ_TABLE_PAGE = ".rwiz0003";	
	
	//test association preference page
	public static final String ASSOC_PREF_CONT = ".tasp0001";	
	
	//execution editor
	public static final String EXEC_EDIT_OVERVIEW = ".exed0001";	
	public static final String EXEC_EDIT_EVENTS = ".exed0002";	

	// Added to support datapool editing (PBS 12/06/03)
	// datapool editor
	public static final String DATA_FORM = ".datf0001";	
	public static final String DATA_TEXT_FORM = ".datf0002";		
	public static final String DATA_NAME_FORM = ".datf0003";
	
	public static final String DATA_TABLE_FORM = ".datbf0001";	
	
	// insert column action
	public static final String INS_COL_ACT = ".ica0001";	
	// delete column action
	public static final String DEL_COL_ACT = ".dca0001";		
	// edit column action
	public static final String EDIT_COL_ACT = ".eca0001";			
	// insert row action
	public static final String INS_ROW_ACT = ".ira0001";		
	// delete row action
	public static final String DEL_ROW_ACT = ".dra0001";			
	// edit row action
	public static final String EDIT_ROW_ACT = ".era0001";				
	// insert row group action
	public static final String INS_ROW_GRP_ACT = ".irga0001";		
	// delete row group action
	public static final String DEL_ROW_GRP_ACT = ".drga0001";			
	// edit row group action
	public static final String EDIT_ROW_GRP_ACT = ".erga0001";				
		
}
